//[mahjong-utils](../../index.md)/[mahjongutils.shanten](index.md)/[asWithoutGot](as-without-got.md)

# asWithoutGot

[common]\
val [CommonShanten](-common-shanten/index.md).[asWithoutGot](as-without-got.md): [ShantenWithoutGot](-shanten-without-got/index.md)
